@@ -29,13 +29,17 @@ regroup <- function(x, groups = NULL){
   # due to NSE notes in R CMD check
   ..count_var <- . <- NULL
 
-  if (!inherits(x, "incidence_df")) abort("x should be an 'incidence_df' object.")
+  if (!inherits(x, "incidence_df")) {
+    abort("x should be an 'incidence_df' object.")
+  }
 
   # check groups present
   groups <- rlang::enquo(groups)
   idx <- tidyselect::eval_select(groups, x)
   groups <- names(x)[idx]
-  if (length(groups) == 0) groups <- NULL
+  if (length(groups) == 0) {
+    groups <- NULL
+  }
 
   date_var <- get_dates_name(x)
   count_var <- get_count_names(x)
